@@ -17,7 +17,7 @@
 """Convenience module for loading public API."""
 
 from .attribute import AttributeDescriptor as ElkAttribute
-from .meta import ElkMeta, ElkRole, Elk
+from .meta import ElkRole, Elk
 from .modifier import before, after, around
 
-__version__ = '0.1'
+__version__ = '0.2'
